% This module creates the random samples to be used in the MC study. Data
% is created from a trivariate normal with X and Z mapped into [0,1]

% Set the random number generator seed
rand('state',8); randn('state',8);

% We begin by specifying the desired sample size and number of replications
SampleSize = 500;
Replications = 500;
X = zeros(SampleSize,Replications);
Z = zeros(SampleSize,Replications);
E = zeros(SampleSize,Replications);

parfor r = 1:Replications
    T = mvnrnd(zeros(SampleSize,3), [1 0.5 0.3; 0.5 1 0; 0.3 0 1]);
    X(:,r) = 2*(normcdf(T(:,1)/3) - 0.5);
    Z(:,r) = 2*(normcdf(T(:,2)/3) - 0.5);
    E(:,r) = T(:,3);
end

% Sort the data
parfor i = 1:Replications
    [X(:,i) I] = sort(X(:,i));
    T = Z(:,i); Z(:,i) = T(I);
    T = E(:,i); E(:,i) = T(I);
end

% Clear up what is not needed
clear i T I;

save MCDataS500R500;