function [obj, g] = func(theta,BData,VIT,lambda)

% Break up theta into two one k_n, one b_n. The same for simplicity
Stheta = theta(1:length(theta)/2);
Btheta = theta(length(theta)/2+1:end);

% Break up the data as it is coming from bootstrap sample
BY = BData(1:length(BData)/2,1); 
BZ = BData(1:length(BData)/2,2); 
BXS = BData(1:length(BData)/2,3:end);

Y = BData(length(BData)/2+1:end,1); 
Z = BData(length(BData)/2+1:end,2); 
XSplines = BData(length(BData)/2+1:end,3:end);

% Obtain the test functions
TFunc = normpdf((repmat(Z, 1, length(VIT)) - repmat(VIT,length(Z),1))/0.05);
TFunc = [TFunc normpdf((repmat(Z, 1, length(VIT)) - repmat(VIT,length(Z),1))/0.2)];
BTFunc = normpdf((repmat(BZ, 1, length(VIT)) - repmat(VIT,length(BZ),1))/0.05);
BTFunc = [BTFunc normpdf((repmat(BZ, 1, length(VIT)) - repmat(VIT,length(BZ),1))/0.2)];

% Calculate the objective function - First residuals
U = repmat(Y - XSplines*Stheta,1,size(TFunc,2)).*TFunc;
UB = repmat(BY - BXS*Stheta,1,size(BTFunc,2)).*BTFunc;

% And the adjustment function
V = repmat(XSplines*Btheta,1,size(TFunc,2)).*TFunc;

% Finally combine into the objective
Gt = (sqrt(length(Y))*(mean(UB) - mean(U)) - mean(V));
Pt = sqrt(lambda)*mean(U);

% Get the final thing
obj = (Gt.^2 + Pt.^2)';

% Get the gradient, but only if requested
if nargout > 1    
    % First get gradients for Theta_n
    XGrad1 = repmat(BTFunc,[1 1 size(BXS,2)]).*permute(repmat(BXS,[1 1 size(BTFunc,2)]),[1 3 2]);
    XGrad2 = repmat(TFunc,[1 1 size(XSplines,2)]).*permute(repmat(XSplines,[1 1 size(TFunc,2)]),[1 3 2]);    
    
    % And the derivative
    gt = -2*sqrt(length(Y))*repmat(Gt,size(XSplines,2),1).*(squeeze(mean(XGrad1,1))' - squeeze(mean(XGrad2,1))') - 2*sqrt(lambda).*repmat(Pt,size(XSplines,2),1).*(squeeze(mean(XGrad2,1))');    
    
    % Now get it for the v minimization - First gradient then rest
    VGrad = repmat(TFunc,[1 1 size(XSplines,2)]).*permute(repmat(XSplines,[1 1 size(TFunc,2)]),[1 3 2]);
    VGrad = squeeze(mean(VGrad,1))';
    gv =  -2*repmat(Gt,size(XSplines,2),1).*VGrad;        
    
    % And put them together
    g = [gt; gv];        
end